@@ -1,29 +1,8 @@
-/****************************************************************************
-**
-** Copyright (C) 2018 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2018 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "perfprofilerstatisticsmodel.h"
+#include "perfprofilertr.h"
 
 #include <utils/qtcassert.h>
 
@@ -33,19 +12,19 @@ namespace PerfProfiler {
 namespace Internal {
 
 static const char *headerLabels[] = {
-    QT_TRANSLATE_NOOP("PerfProfilerStatisticsView", "Address"),
-    QT_TRANSLATE_NOOP("PerfProfilerStatisticsView", "Function"),
-    QT_TRANSLATE_NOOP("PerfProfilerStatisticsView", "Source Location"),
-    QT_TRANSLATE_NOOP("PerfProfilerStatisticsView", "Binary Location"),
-    QT_TRANSLATE_NOOP("PerfProfilerStatisticsView", "Caller"),
-    QT_TRANSLATE_NOOP("PerfProfilerStatisticsView", "Callee"),
-    QT_TRANSLATE_NOOP("PerfProfilerStatisticsView", "Occurrences"),
-    QT_TRANSLATE_NOOP("PerfProfilerStatisticsView", "Occurrences in Percent"),
-    QT_TRANSLATE_NOOP("PerfProfilerStatisticsView", "Recursion in Percent"),
-    QT_TRANSLATE_NOOP("PerfProfilerStatisticsView", "Samples"),
-    QT_TRANSLATE_NOOP("PerfProfilerStatisticsView", "Samples in Percent"),
-    QT_TRANSLATE_NOOP("PerfProfilerStatisticsView", "Self Samples"),
-    QT_TRANSLATE_NOOP("PerfProfilerStatisticsView", "Self in Percent")
+    QT_TRANSLATE_NOOP("QtC::PerfProfiler", "Address"),
+    QT_TRANSLATE_NOOP("QtC::PerfProfiler", "Function"),
+    QT_TRANSLATE_NOOP("QtC::PerfProfiler", "Source Location"),
+    QT_TRANSLATE_NOOP("QtC::PerfProfiler", "Binary Location"),
+    QT_TRANSLATE_NOOP("QtC::PerfProfiler", "Caller"),
+    QT_TRANSLATE_NOOP("QtC::PerfProfiler", "Callee"),
+    QT_TRANSLATE_NOOP("QtC::PerfProfiler", "Occurrences"),
+    QT_TRANSLATE_NOOP("QtC::PerfProfiler", "Occurrences in Percent"),
+    QT_TRANSLATE_NOOP("QtC::PerfProfiler", "Recursion in Percent"),
+    QT_TRANSLATE_NOOP("QtC::PerfProfiler", "Samples"),
+    QT_TRANSLATE_NOOP("QtC::PerfProfiler", "Samples in Percent"),
+    QT_TRANSLATE_NOOP("QtC::PerfProfiler", "Self Samples"),
+    QT_TRANSLATE_NOOP("QtC::PerfProfiler", "Self in Percent")
 };
 
 Q_STATIC_ASSERT(sizeof(headerLabels) ==
@@ -124,7 +103,7 @@ QVariant PerfProfilerStatisticsModel::headerData(int section, Qt::Orientation or
     if (role != Qt::DisplayRole || orientation != Qt::Horizontal)
         return QVariant();
 
-    return tr(headerLabels[m_columns[section]]);
+    return Tr::tr(headerLabels[m_columns[section]]);
 }
 
 void PerfProfilerStatisticsMainModel::resort()
@@ -171,7 +150,7 @@ QByteArray PerfProfilerStatisticsMainModel::metaInfo(
         int typeId, PerfProfilerStatisticsModel::Column column) const
 {
     // Need to look up stuff from tracemanager
-    PerfProfilerTraceManager *manager = static_cast<PerfProfilerTraceManager *>(QObject::parent());
+    PerfProfilerTraceManager *manager = &traceManager();
     switch (column) {
     case BinaryLocation:
     case Function: {
@@ -195,9 +174,7 @@ QByteArray PerfProfilerStatisticsMainModel::metaInfo(
 
 quint64 PerfProfilerStatisticsMainModel::address(int typeId) const
 {
-    PerfProfilerTraceManager *manager =
-            static_cast<PerfProfilerTraceManager *>(QObject::parent());
-    return manager->location(typeId).address;
+    return traceManager().location(typeId).address;
 }
 
 void PerfProfilerStatisticsMainModel::initialize()
@@ -339,14 +316,14 @@ int PerfProfilerStatisticsMainModel::rowForTypeId(int typeId) const
     return m_backwardIndex[static_cast<int>(it - m_data.begin())];
 }
 
-PerfProfilerStatisticsMainModel::PerfProfilerStatisticsMainModel(PerfProfilerTraceManager *parent) :
+PerfProfilerStatisticsMainModel::PerfProfilerStatisticsMainModel(QObject *parent) :
     PerfProfilerStatisticsModel(Main, parent), m_startTime(std::numeric_limits<qint64>::min()),
     m_endTime(std::numeric_limits<qint64>::max()), m_totalSamples(0)
 {
     m_children = new PerfProfilerStatisticsRelativesModel(Children, this);
     m_parents = new PerfProfilerStatisticsRelativesModel(Parents, this);
     PerfProfilerStatisticsData *data = new PerfProfilerStatisticsData;
-    parent->registerFeatures(PerfEventType::attributeFeatures(),
+    traceManager().registerFeatures(PerfEventType::attributeFeatures(),
                              std::bind(&PerfProfilerStatisticsData::loadEvent, data,
                                        std::placeholders::_1, std::placeholders::_2),
                              std::bind(&PerfProfilerStatisticsMainModel::initialize, this),
